@@ -34,7 +34,7 @@ our @EXPORT_OK =
   qw(BY_XPATH BY_ID BY_NAME BY_TAG BY_CLASS BY_SELECTOR BY_LINK BY_PARTIAL);
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 sub _ANYPROCESS                    { return -1 }
 sub _COMMAND                       { return 0 }
@@ -113,8 +113,8 @@ sub _setup_arguments {
             $self->{visible} = 0;
         }
         elsif (( $OSNAME eq 'MSWin32' )
-            || ( $OSNAME ne 'darwin' )
-            || ( $OSNAME ne 'cygwin' ) )
+            || ( $OSNAME eq 'darwin' )
+            || ( $OSNAME eq 'cygwin' ) )
         {
         }
         else {
@@ -2280,7 +2280,7 @@ Firefox::Marionette - Automate the Firefox browser with the Marionette protocol
 
 =head1 VERSION
 
-Version 0.36
+Version 0.37
 
 =head1 SYNOPSIS
 
